package ru.skipy.ui.components.sft;

import ru.skipy.filtering.Filterable;

/**
 * This class represents table row in {@link SnFTableModel}.
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public class TableRow implements Filterable {

    /**
     * Row data
     */
    private Object[] data;


    /**
     * Package constructor. Constructs object and copies data array passed.
     *
     * @param data array of data.
     */
    TableRow(Object[] data) {
        this.data = new Object[data.length];
        System.arraycopy(data, 0, this.data, 0, data.length);
    }


    /**
     * Returns object by it's index in the row. Object returned have a class
     * equal to <code>clazz</code> parameter
     *
     * @param index object's index
     * @param clazz required object's class
     *
     * @return data object of class <code>clazz</code>
     *
     * @throws IllegalArgumentException if index is out of array bounds
     * @throws IllegalArgumentException if object can't be casted to class specified
     */
    public <T> T getCastedObjectAt(int index, Class<T> clazz) {
        Object dataObject = getObjectAt(index);
        if (!clazz.isAssignableFrom(dataObject.getClass())) {
            throw new IllegalArgumentException("Class passed is invalid: " + clazz.getName() + ". Should be " + dataObject.getClass()
                .getName() + " or it's ancestor");
        }
        return clazz.cast(dataObject);
    }


    /**
     * Returns object by it's index in the row.
     *
     * @param index object's index
     *
     * @return data object
     *
     * @throws IllegalArgumentException if index is out of array bounds
     */
    public Object getObjectAt(int index) {
        if (index < 0 || index >= data.length) {
            throw new IllegalArgumentException(
                "Array index is invalid: " + index + ". Should be in [0," + data.length + "] range.");
        }
        return data[index];
    }

}
