/**
 * TableRowBuilderFactory
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.components.sft;

import java.util.HashMap;
import java.util.Map;

/**
 * Table row builder factory. Constructs {@link TableRowBuilder}s by request.
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
final class TableRowBuilderFactory {

    /**
     * Table row builders' cache
     */
    private static Map<TableRowBuilder.Id, TableRowBuilder> builders = new HashMap<TableRowBuilder.Id, TableRowBuilder>();


    /**
     * Empty private constructor to prevent instance creation
     */
    private TableRowBuilderFactory() {
    }


    /**
     * Returns {@link TableRowBuilder} for the specified column classes array. If builder
     * wasn't created yet creates and caches one. Table row buildera are identified by
     * their {@link TableRowBuilder.Id}s
     *
     * @param columnClasses column classes array for which {@link TableRow} builder is equired.
     *
     * @return table row builder
     */
    public static TableRowBuilder getInstance(Class[] columnClasses) {
        TableRowBuilder.Id id = TableRowBuilder.getId(columnClasses);
        TableRowBuilder builder = builders.get(id);
        if (builder == null) {
            builder = new TableRowBuilder(columnClasses);
            builders.put(id, builder);
        }
        return builder;
    }

}
