/**
 * FemaleFilter
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.filters;

import ru.skipy.filtering.Filter;
import ru.skipy.ui.components.sft.TableRow;
import ru.skipy.ui.test.sft.data.DataHolder;
import ru.skipy.ui.test.sft.datatypes.Gender;

/**
 * FemaleFilter
 *
 * This filter accepts only table rows with {@link Gender#female} as gender
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public class FemaleFilter implements Filter<TableRow> {

    /**
     * Checks if row should be accepted
     *
     * @param tableRow row to check
     *
     * @return <code>true</code>, if 'gender' column of the row contain {@link Gender#female};
     *         <code>false</code> otherwise
     */
    public boolean accept(TableRow tableRow) {
        return tableRow.getCastedObjectAt(DataHolder.GENDER_IDX, Gender.class).equals(Gender.female);
    }


    /**
     * Returns filter name
     *
     * @return filter name
     */
    public String getName() {
        return "Females only";
    }


    /**
     * Returns filter description
     *
     * @return filter description
     */
    public String getDescription() {
        return "Accepts only females";
    }


    /**
     * Returns filter rule in humanreadable form
     *
     * @return filter rule
     */
    public String getHumanreadableRule() {
        return "gender==female";
    }


    /**
     * Retuans filter's string representation (the same as name)
     *
     * @return filter's string representation
     */
    public String toString() {
        return getName();
    }

}
