/**
 * ControlPanel
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.ui;

import java.awt.GridLayout;
import java.awt.event.ItemEvent;
import java.awt.event.ItemListener;
import javax.swing.*;

import ru.skipy.filtering.Filter;
import ru.skipy.ui.components.sft.*;
import ru.skipy.ui.test.sft.data.DataHolder;
import ru.skipy.ui.test.sft.filters.CellularPhoneFilter;
import ru.skipy.ui.test.sft.filters.FemaleFilter;
import ru.skipy.ui.test.sft.sorters.Sorter;

/**
 * ControlPanel
 *
 * This panel contains two comboboxes for {@link SnFTableModel} control - one for
 * sorters and one for filters
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public class ControlPanel extends JPanel {

    /**
     * Filters list
     */
    private JComboBox filters;

    /**
     * Sorters list
     */
    private JComboBox sorters;

    /**
     * Table model
     */
    private SnFTableModel model;


    /**
     * Constructs control panel
     *
     * @param model table model to control
     */
    public ControlPanel(SnFTableModel model) {
        super();
        this.model = model;
        GridLayout layout = new GridLayout(2, 1, 5, 5);
        setLayout(layout);
        filters = new JComboBox(new Object[]{"No filter", new CellularPhoneFilter(), new FemaleFilter()});
        sorters = new JComboBox(new Object[]{
            "No sort", new Sorter(new ColumnSortPrefs[]{
                new ColumnSortPrefs(DataHolder.GENDER_IDX, SortMode.ASCENDING),
                new ColumnSortPrefs(DataHolder.NAME_IDX, SortMode.DESCENDING)
            },
                "Sort by gender(asc), then name(desc)"), new Sorter(new ColumnSortPrefs[]{
                    new ColumnSortPrefs(DataHolder.PHONE_IDX, SortMode.ASCENDING)
                }, "Sort by phone(asc)")
        });
        add(filters);
        add(sorters);
        setBorder(BorderFactory.createEmptyBorder(5, 5, 5, 5));
        filters.addItemListener(new FiltersItemListener());
        sorters.addItemListener(new SortersItemListener());
    }


    /**
     * Filters change handler
     */
    private class FiltersItemListener implements ItemListener {

        /**
         * Handles combobox item selection change event. Selected filter has been
         * applied onto model.
         *
         * @param e change event
         */
        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.DESELECTED) {
                return;
            }
            Object item = e.getItem();
            if (item instanceof Filter) {
                model.setFilter((Filter<TableRow>)item, true);
            } else {
                model.dropFilter();
            }
        }

    }

    /**
     * Sorters change handler
     */
    private class SortersItemListener implements ItemListener {

        /**
         * Handles combobox item selection change event. Selected sorter has been
         * applied onto model.
         *
         * @param e change event
         */
        public void itemStateChanged(ItemEvent e) {
            if (e.getStateChange() == ItemEvent.DESELECTED) {
                return;
            }
            Object item = e.getItem();
            if (item instanceof Sorter) {
                model.setSortPreferences(((Sorter)item).getPrefs(), true);
            } else {
                model.dropSortPreferences();
            }
        }

    }
}
