/**
 * SnFTableTestFrame
 *
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.ui;

import java.awt.*;
import javax.swing.*;

import ru.skipy.ui.components.sft.SnFTableModel;
import ru.skipy.ui.test.sft.data.DataHolder;
import ru.skipy.ui.test.sft.datatypes.*;

/**
 * Main example frame. It contains table and {@link ControlPanel} with two comboboxes -
 * one for filters and one for sorters.
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
public class SnFTableTestFrame extends JFrame {

    /**
     * Table model
     */
    private SnFTableModel model;


    /**
     * Constructs example frame
     */
    public SnFTableTestFrame() {
        super("SnFTable test");
        model = new SnFTableModel(DataHolder.COLUMN_CLASSES, DataHolder.COLUMN_NAMES, DataHolder.DATA);
        model.registerComparatorForClass(PhoneNumber.class, PhoneNumberComparators.INSTANCE);
        model.registerComparatorForClass(Gender.class, GenderComparator.INSTANCE);
        JTable table = new JTable(model);
        table.setDefaultRenderer(String.class, new NameCellRenderer(model));
        table.setDefaultRenderer(PhoneNumber.class, new PhoneCellRenderer(model));
        table.setDefaultRenderer(Gender.class, new GenderCellRenderer(model));
        JPanel tablePane = new JPanel();
        tablePane.setLayout(new BorderLayout());
        tablePane.add(table, BorderLayout.CENTER);
        tablePane.add(table.getTableHeader(), BorderLayout.NORTH);
        tablePane.setBorder(BorderFactory.createCompoundBorder(BorderFactory.createEmptyBorder(5, 5, 0, 5),
            BorderFactory.createLineBorder(Color.darkGray, 1)));
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        getContentPane().add(tablePane, BorderLayout.CENTER);
        getContentPane().add(new ControlPanel(model), BorderLayout.SOUTH);
        pack();
        setSize(400, getHeight());
        Dimension screen = Toolkit.getDefaultToolkit().getScreenSize();
        setLocation((screen.width - getWidth()) / 2, (screen.height - getHeight()) / 2);
    }


}
