/**
 * SnFTestCellRenderer
 * 
 * Copyright (c) 2005 Eugene Matyushkin (E-mail: skipy@mail.ru)
 *
 * License agreement:
 *
 * 1. This code is published AS IS. Author is not responsible for any damage that can be
 *    caused by any application that uses this code.
 * 2. Author does not give a garantee, that this code is error free.
 * 3. This code can be used in NON-COMMERCIAL applications AS IS without any special
 *    permission from author.
 * 4. This code can be modified without any special permission from author IF AND ONLY IF
 *    this license agreement will remain unchanged.
 * 5. SPECIAL PERMISSION for this code usage in COMMERCIAL application SHOULD be obtained
 *    from author.
 */
package ru.skipy.ui.test.sft.ui;

import java.awt.Color;
import javax.swing.BorderFactory;
import javax.swing.JLabel;
import javax.swing.table.TableCellRenderer;

import ru.skipy.ui.components.sft.SnFTableModel;
import ru.skipy.ui.test.sft.data.DataHolder;
import ru.skipy.ui.test.sft.datatypes.Gender;

/**
 * SnFTestCellRenderer
 *
 * This is a base for all cell renderers of this example.<br><br>
 *
 * If row is not selected, it sets black foreground color and light blue background
 * color for rows with gender equals to {@link Gender#male}, COLOR_ROSE color for rows with
 * gender equals to {@link Gender#female} and while for all other rows.<br><br>
 *
 * If row not selected, it sets white foreground color and blue background color.
 *
 * @author Eugene Matyushkin
 * @version 1.0
 */
abstract class SnFTestCellRenderer extends JLabel implements TableCellRenderer {

    /**
     * Rose color constant
     */
    protected final Color COLOR_ROSE = new Color(0xff, 0xf0, 0xf0);

    /**
     * Light blue color constant
     */
    protected final Color COLOR_LIGHT_BLUE = new Color(0xf0, 0xf8, 0xff);

    /**
     * Table model
     */
    protected SnFTableModel model;


    /**
     * Constructs cell renderer
     *
     * @param model table model
     */
    protected SnFTestCellRenderer(SnFTableModel model) {
        super();
        this.model = model;
        setOpaque(true);
        setBorder(BorderFactory.createEmptyBorder(2, 5, 2, 5));
    }


    /**
     * Sets color depengind on row number and selection
     *
     * @param isSelected if row is selected
     * @param row        row number
     */
    protected void setColors(boolean isSelected, int row) {
        if (isSelected) {
            setForeground(Color.white);
            setBackground(Color.blue);
        } else {
            setForeground(Color.black);
            Gender gender = (Gender)model.getValueAt(row, DataHolder.GENDER_IDX);
            switch (gender) {
                case male:
                    {
                        setBackground(COLOR_LIGHT_BLUE);
                        break;
                    }
                case female:
                    {
                        setBackground(COLOR_ROSE);
                        break;
                    }
                default:
                    {
                        setBackground(Color.white);
                    }
            }
        }
    }

}
